@@ -19,6 +19,9 @@ def print_console(msg, level=INFO, formatter=0):
     tabs, color = ["", ""]
     for _ in range(formatter):
         tabs += "    "
+    if os.name == 'nt':
+        print(tabs + msg)
+        return
     if level == ERROR:
         color = Fore.RED
     elif level == WARNING:
@@ -34,13 +37,40 @@ def host_platform():
     return "unix"
 
 
+# TODO :improve to support all archs
+def host_distname():
+    try:
+        sysname = os.uname().sysname
+        machine = os.uname().machine
+    except:
+        sysname = "w64"
+        machine = "amd64"
+    if sysname == "Darwin":
+        if machine == "x86_64":
+            return "mac_x64"
+        if machine == "arm64":
+            return "mac_arm64"
+        return None
+    if sysname == "Linux":
+        if not os.path.exists("/usr/bin/dpkg"):
+            return None
+        if machine == "x86_64":
+            return "deb_x64"
+        return "deb_i386"
+    if os.name == "nt":
+        return "w64"
+    if os.path.isfile("/default.prop"):
+        return "android"
+    return None
+
+
 def git_fetch(url, version, source_path):
     if os.path.isdir(os.path.join(source_path, ".git")):
         repo = Repo(source_path)
         repo.remotes.origin.pull("master")
     else:
         repo = Repo.clone_from(url, source_path)
-    if version != "latest":
+    if version != "git":
         repo.git.checkout(version)
 
 
